From 00f1a668cd5b2b836a7d6d0474e181feca7e6814 Mon Sep 17 00:00:00 2001
From: nutlope
Date: Fri, 22 Sep 2023 15:49:02 -0400
Subject: [PATCH] increased rate limit, edited README
---
README.md | 12 ++----------
app/api/generate/route.ts | 4 ++--
2 files changed, 4 insertions(+), 12 deletions(-)
diff --git a/README.md b/README.md
index 6a375a2..a09acd7 100644
--- a/README.md
+++ b/README.md
@@ -7,17 +7,9 @@
Generate beautiful AI QR Codes in seconds. Powered by Vercel and Replicate.
-
-
+
@@ -41,7 +33,7 @@
You can deploy this template to Vercel with the button below:
-
+[![Deploy with Vercel](https://vercel.com/button)](https://vercel.fyi/qrGPT)
Note that you'll need to:
diff --git a/app/api/generate/route.ts b/app/api/generate/route.ts
index ae5c9ae..5460af2 100644
--- a/app/api/generate/route.ts
+++ b/app/api/generate/route.ts
@@ -24,8 +24,8 @@ const validateRequest = (request: QrGenerateRequest) => {
const ratelimit = new Ratelimit({
redis: kv,
- // Allow 15 requests from the same IP in 1 day.
- limiter: Ratelimit.slidingWindow(15, '1 d'),
+ // Allow 20 requests from the same IP in 1 day.
+ limiter: Ratelimit.slidingWindow(20, '1 d'),
});
export async function POST(request: NextRequest) {